Struct remi_fs::StorageService

source ·
pub struct StorageService { /* private fields */ }
Represents an implementation of a StorageService for the local filesystem.

Implementations

source

impl StorageService

source

pub fn new<P: AsRef<Path>>(path: P) -> StorageService

Creates a new StorageService instance.

source

pub fn with_config(config: Config) -> StorageService

Creates a new StorageService instance with a provided configuration object.

source

pub fn with_resolver<R: ContentTypeResolver + 'static>( self, resolver: R ) -> StorageService

Updates the given ContentTypeResolver to something else.

source

pub fn normalize<P: AsRef<Path>>(&self, path: P) -> Result<Option<PathBuf>>

Attempts to normalize a given path and returns a canonical, absolute path. It must follow some strict rules:

  • If the path starts with ./, then it will resolve from Config::directory if the directory was found. Otherwise, it’ll use the current directory.

  • If the path starts with ~/, then it will resolve from the home directory from dirs::home_dir.