Struct remi_fs::StorageService
source · pub struct StorageService { /* private fields */ }Expand description
Represents an implementation of a StorageService for the
local filesystem.
Implementations
sourceimpl StorageService
impl StorageService
sourcepub fn new<P: AsRef<Path>>(path: P) -> StorageService
pub fn new<P: AsRef<Path>>(path: P) -> StorageService
Creates a new StorageService instance.
sourcepub fn with_config(config: Config) -> StorageService
pub fn with_config(config: Config) -> StorageService
Creates a new StorageService instance with a provided configuration object.
sourcepub fn with_resolver<R: ContentTypeResolver + 'static>(
self,
resolver: R
) -> StorageService
pub fn with_resolver<R: ContentTypeResolver + 'static>( self, resolver: R ) -> StorageService
Updates the given ContentTypeResolver to something else.
sourcepub fn normalize<P: AsRef<Path>>(&self, path: P) -> Result<Option<PathBuf>>
pub fn normalize<P: AsRef<Path>>(&self, path: P) -> Result<Option<PathBuf>>
Attempts to normalize a given path and returns a canonical, absolute path. It must follow some strict rules:
-
If the path starts with
./, then it will resolve fromConfig::directoryif the directory was found. Otherwise, it’ll use the current directory. -
If the path starts with
~/, then it will resolve from the home directory fromdirs::home_dir.